@@ -7,25 +7,37 @@ forms, including automatic selection of elements, degrees and
 form representation type.
 """
 
-__author__ = "Anders Logg (logg@simula.no) and Kristian B. Oelgaard (k.b.oelgaard@gmail.com)"
-__date__ = "2007-02-05"
-__copyright__ = "Copyright (C) 2007-2010 " + __author__
-__license__  = "GNU GPL version 3 or any later version"
-
+# Copyright (C) 2007-2010 Anders Logg and Kristian B. Oelgaard
+#
+# This file is part of FFC.
+#
+# FFC is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# FFC is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with FFC. If not, see <http://www.gnu.org/licenses/>.
+#
 # Modified by Marie E. Rognes, 2010
-
-# Last changed: 2011-01-13
+#
+# First added:  2007-02-05
+# Last changed: 2011-05-02
 
 # UFL modules
 from ufl.common import istr, tstr
 from ufl.integral import Measure
 from ufl.finiteelement import MixedElement, EnrichedElement
-from ufl.algorithms import preprocess
-from ufl.algorithms import estimate_max_polynomial_degree
 from ufl.algorithms import estimate_total_polynomial_degree
-from ufl.algorithms import extract_unique_elements
 from ufl.algorithms import sort_elements
 from ufl.algorithms import compute_form_arities
+from ufl.algorithms import extract_elements, extract_sub_elements
+from ufl.algorithms import extract_common_cell
 
 # FFC modules
 from ffc.log import log, info, begin, end, warning, debug, error, ffc_assert
@@ -38,63 +50,74 @@ def analyze_forms(forms, object_names, parameters, common_cell=None):
     """
     Analyze form(s), returning
 
-       forms           - a tuple of preprocessed forms
+       form_datas      - a tuple of form_data objects
        unique_elements - a tuple of unique elements across all forms
-       element_map     - a map from elements to unique element numbers
+       element_numbers - a mapping to unique numbers for all elements
     """
 
     begin("Compiler stage 1: Analyzing form(s)")
 
     # Analyze forms
-    forms = tuple(_analyze_form(form, object_names, parameters, common_cell) for form in forms)
+    form_datas = tuple(_analyze_form(form,
+                                     object_names,
+                                     parameters,
+                                     common_cell) for form in forms)
 
-    # Extract unique elements
+    # Extract unique elements accross all forms
     unique_elements = []
-    for form in forms:
-        for element in form.form_data().unique_sub_elements:
+    for form_data in form_datas:
+        for element in form_data.unique_sub_elements:
             if not element in unique_elements:
                 unique_elements.append(element)
 
     # Sort elements
     unique_elements = sort_elements(unique_elements)
 
-    # Build element map
-    element_map = _build_element_map(unique_elements)
+    # Compute element numbers
+    element_numbers = _compute_element_numbers(unique_elements)
 
     end()
 
-    return forms, unique_elements, element_map
+    return form_datas, unique_elements, element_numbers
 
-def analyze_elements(elements):
+def analyze_elements(elements, parameters):
 
     begin("Compiler stage 1: Analyzing form(s)")
 
     # Extract unique elements
     unique_elements = []
-    element_map = {}
+    element_numbers = {}
     for element in elements:
         # Get all (unique) nested elements.
         for e in _get_nested_elements(element):
             # Check if element is present
-            if not e in element_map:
-                element_map[e] = len(unique_elements)
+            if not e in element_numbers:
+                element_numbers[e] = len(unique_elements)
                 unique_elements.append(e)
+
     # Sort elements
     unique_elements = sort_elements(unique_elements)
 
     # Build element map
-    element_map = _build_element_map(unique_elements)
+    element_numbers = _compute_element_numbers(unique_elements)
 
+    # Update scheme for QuadratureElements
+    scheme = parameters["quadrature_rule"]
+    if scheme == "auto":
+        scheme = "default"
+    for element in unique_elements:
+        if element.family() == "Quadrature":
+            element._quad_scheme = scheme
     end()
 
-    return (), unique_elements, element_map
+    return (), unique_elements, element_numbers
 
-def _build_element_map(elements):
+def _compute_element_numbers(elements):
     "Build map from elements to element numbers."
-    element_map = {}
+    element_numbers = {}
     for (i, element) in enumerate(elements):
-        element_map[element] = i
-    return element_map
+        element_numbers[element] = i
+    return element_numbers
 
 def _get_nested_elements(element):
     "Get unique nested elements (including self)."
@@ -110,66 +133,37 @@ def _analyze_form(form, object_names, parameters, common_cell=None):
     ffc_assert(len(form.integrals()),
                "Form (%s) seems to be zero: cannot compile it." % str(form))
 
-    # Preprocess form if necessary
-    if form.form_data() is None:
-        form = preprocess(form, object_names, common_cell)
+    # Compute element mapping for element replacement
+    element_mapping = _compute_element_mapping(form, common_cell)
+
+    # Compute form metadata
+    form_data = form.compute_form_data(object_names=object_names,
+                                       common_cell=common_cell,
+                                       element_mapping=element_mapping)
+
     info("")
-    info(str(form.form_data()))
+    info(str(form_data))
+
+    # Extract preprocessed form
+    preprocessed_form = form_data.preprocessed_form
 
     # Check that all terms in form have same arity
-    ffc_assert(len(compute_form_arities(form)) == 1,
+    ffc_assert(len(compute_form_arities(preprocessed_form)) == 1,
                "All terms in form must have same rank.")
 
-    # Adjust cell and degree for elements when unspecified
-    _adjust_elements(form.form_data())
+    # Attach integral meta data
+    _attach_integral_metadata(form_data, common_cell, parameters)
 
-    # Extract integral metadata
-    _extract_metadata(form.form_data(), parameters)
+    return form_data
 
-    return form
-
-def _adjust_elements(form_data):
-    "Adjust cell and degree for elements when unspecified."
-
-    # Note the importance of consider form_data.sub_elements here
-    # instead of form_data.unique_sub_elements. This is because
-    # elements considered equal (same output from __repr__) will not
-    # be repeated in unique_sub_elements but all elements need to be
-    # adjusted.
-
-    # Extract common cell
-    common_cell = form_data.cell
-    if common_cell.domain() is None:
-        error("Missing cell definition in form.")
-
-    # Extract common degree
-    common_degree = max([element.degree() for element in form_data.sub_elements])
-    if common_degree is None:
-        common_degree = default_quadrature_degree
-
-    # Degree must be at least 1 (to work with Lagrange elements)
-    common_degree = max(1, common_degree)
-
-    # Set cell and degree if missing
-    for element in form_data.sub_elements:
-
-        # Check if cell and degree need to be adjusted
-        cell = element.cell()
-        degree = element.degree()
-        if degree is None:
-            info("Adjusting element degree from %s to %d" % (istr(degree), common_degree))
-            element.set_degree(common_degree)
-        if cell.domain() is None:
-            info("Adjusting element cell from %s to %s." % (istr(cell), str(common_cell)))
-            element.set_cell(common_cell)
-
-def _extract_metadata(form_data, parameters):
-    "Attach and group meta data for each subdomain integral collection."
+def _attach_integral_metadata(form_data, common_cell, parameters):
+    "Attach integral metadata"
 
     # Recognized metadata keys
     metadata_keys = ("representation", "quadrature_degree", "quadrature_rule")
 
     # Iterate over integral collections
+    quad_schemes = []
     for (domain_type, domain_id, integrals, metadata) in form_data.integral_data:
 
         # Iterate over integrals
@@ -183,32 +177,49 @@ def _extract_metadata(form_data, parameters):
                     integral_metadata[key] = parameters[key]
 
             # Check metadata
-            r = integral_metadata["representation"]
-            q = integral_metadata["quadrature_degree"]
+            r  = integral_metadata["representation"]
+            qd = integral_metadata["quadrature_degree"]
+            qr = integral_metadata["quadrature_rule"]
             if not r in ("quadrature", "tensor", "auto"):
                 info("Valid choices are 'tensor', 'quadrature' or 'auto'.")
                 error("Illegal choice of representation for integral: " + str(r))
-            if not q == "auto":
-                q = int(q)
-                if not q >= 0:
+            if not qd  == "auto":
+                qd = int(qd)
+                if not qd >= 0:
                     info("Valid choices are nonnegative integers or 'auto'.")
-                    error("Illegal quadrature degree for integral: " + str(q))
+                    error("Illegal quadrature degree for integral: " + str(qd))
+            if not qr in ("default", "canonical", "auto"):
+                info("Valid choices are 'default', 'canonical' or 'auto'.")
+                error("Illegal choice of quadrature rule for integral: " + str(qr))
 
             # Automatic selection of representation
             if r == "auto":
-                r = _auto_select_representation(integral, form_data.unique_sub_elements)
+                r = _auto_select_representation(integral,
+                                                form_data.unique_sub_elements)
                 info("representation:    auto --> %s" % r)
                 integral_metadata["representation"] = r
             else:
                 info("representation:    %s" % r)
 
             # Automatic selection of quadrature degree
-            if q == "auto":
-                q = _auto_select_quadrature_degree(integral, r, form_data.unique_sub_elements)
-                info("quadrature_degree: auto --> %d" % q)
+            if qd == "auto":
+                qd = _auto_select_quadrature_degree(integral,
+                                                    r,
+                                                    form_data.unique_sub_elements)
+                info("quadrature_degree: auto --> %d" % qd)
+                integral_metadata["quadrature_degree"] = qd
             else:
-                info("quadrature_degree: %d" % q)
-            integral_metadata["quadrature_degree"] = q
+                info("quadrature_degree: %d" % qd)
+
+            # Automatic selection of quadrature rule
+            if qr == "auto":
+                # Just use default for now.
+                qr = "default"
+                info("quadrature_rule:   auto --> %s" % qr)
+                integral_metadata["quadrature_rule"] = qr
+            else:
+                info("quadrature_rule:   %s" % qr)
+            quad_schemes.append(qr)
 
             # Append to list of metadata
             integral_metadatas.append(integral_metadata)
@@ -219,6 +230,7 @@ def _extract_metadata(form_data, parameters):
         else:
 
             # Check that representation is the same
+            # FIXME: Why must the representation within a sub domain be the same?
             representations = [md["representation"] for md in integral_metadatas]
             if not all_equal(representations):
                 r = "quadrature"
@@ -227,21 +239,37 @@ def _extract_metadata(form_data, parameters):
                 r = representations[0]
 
             # Check that quadrature degree is the same
+            # FIXME: Why must the degree within a sub domain be the same?
             quadrature_degrees = [md["quadrature_degree"] for md in integral_metadatas]
             if not all_equal(quadrature_degrees):
-                q = max(quadrature_degrees)
-                info("Quadrature degree must be equal within each sub domain, using degree %d." % q)
+                qd = max(quadrature_degrees)
+                info("Quadrature degree must be equal within each sub domain, using degree %d." % qd)
             else:
-                q = quadrature_degrees[0]
+                qd = quadrature_degrees[0]
+
+            # Check that quadrature rule is the same
+            # FIXME: Why must the rule within a sub domain be the same?
+            quadrature_rules = [md["quadrature_rule"] for md in integral_metadatas]
+            if not all_equal(quadrature_rules):
+                qr = "canonical"
+                info("Quadrature rule must be equal within each sub domain, using %s rule." % qr)
+            else:
+                qr = quadrature_rules[0]
 
             # Update common metadata
             metadata["representation"] = r
-            metadata["quadrature_degree"] = q
+            metadata["quadrature_degree"] = qd
+            metadata["quadrature_rule"] = qr
 
-            # Attach quadrature rule (default)
-            metadata["quadrature_rule"] = parameters["quadrature_rule"]
-
-    return metadata
+    # Update scheme for QuadratureElements
+    if not all_equal(quad_schemes):
+        scheme = "canonical"
+        info("Quadrature rule must be equal within each sub domain, using %s rule." % qr)
+    else:
+        scheme = quad_schemes[0]
+    for element in form_data.sub_elements:
+        if element.family() == "Quadrature":
+            element._quad_scheme = scheme
 
 def _get_sub_elements(element):
     "Get sub elements."
@@ -254,6 +282,65 @@ def _get_sub_elements(element):
             sub_elements += _get_sub_elements(e)
     return sub_elements
 
+def _compute_element_mapping(form, common_cell):
+    "Compute element mapping for element replacement"
+
+    # Extract all elements
+    elements = extract_elements(form)
+    elements = extract_sub_elements(elements)
+
+    # Get cell and degree
+    common_cell = extract_common_cell(form, common_cell)
+    common_degree = _auto_select_degree(elements)
+
+    # Compute element map
+    element_mapping = {}
+    for element in elements:
+
+        # Flag for whether element needs to be reconstructed
+        reconstruct = False
+
+        # Set cell
+        cell = element.cell()
+        if cell.is_undefined():
+            info("Adjusting element cell from %s to %s." % \
+                     (istr(cell), str(common_cell)))
+            cell = common_cell
+            reconstruct = True
+
+        # Set degree
+        degree = element.degree()
+        if degree is None:
+            info("Adjusting element degree from %s to %d" % \
+                     (istr(degree), common_degree))
+            degree = common_degree
+            reconstruct = True
+
+        # Reconstruct element and add to map
+        if reconstruct:
+            element_mapping[element] = element.reconstruct(cell=cell,
+                                                           degree=degree)
+
+    return element_mapping
+
+def _auto_select_degree(elements):
+    """
+    Automatically select degree for all elements of the form in cases
+    where this has not been specified by the user. This feature is
+    used by DOLFIN to allow the specification of Expressions with
+    undefined degrees.
+    """
+
+    # Extract common degree
+    common_degree = max([e.degree() for e in elements])
+    if common_degree is None:
+        common_degree = default_quadrature_degree
+
+    # Degree must be at least 1 (to work with Lagrange elements)
+    common_degree = max(1, common_degree)
+
+    return common_degree
+
 def _auto_select_representation(integral, elements):
     """
     Automatically select a suitable representation for integral.
