@@ -89,14 +89,28 @@ The compiler stages are implemented by the following functions:
   format_code       (stage 5)
 """
 
-__author__ = "Anders Logg (logg@simula.no)"
-__date__ = "2007-02-05"
-__copyright__ = "Copyright (C) 2007-2010 " + __author__
-__license__  = "GNU GPL version 3 or any later version"
-
+# Copyright (C) 2007-2010 Anders Logg
+#
+# This file is part of FFC.
+#
+# FFC is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# FFC is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with FFC.  If not, see <http://www.gnu.org/licenses/>.
+#
 # Modified by Kristian B. Oelgaard, 2010.
 # Modified by Dag Lindbo, 2008.
 # Modified by Garth N. Wells, 2009.
+#
+# First added:  2007-02-05
 # Last changed: 2010-01-24
 
 __all__ = ["compile_form", "compile_element"]
@@ -116,7 +130,8 @@ from ffc.codegeneration import generate_code
 from ffc.formatting import format_code
 from ffc.wrappers import generate_wrapper_code
 
-def compile_form(forms, object_names={}, prefix="Form", parameters=default_parameters()):
+def compile_form(forms, object_names={}, prefix="Form",\
+                 parameters=default_parameters(), common_cell=None):
     """This function generates UFC code for a given UFL form or list
     of UFL forms."""
 
@@ -132,7 +147,7 @@ def compile_form(forms, object_names={}, prefix="Form", parameters=default_param
 
     # Stage 1: analysis
     cpu_time = time()
-    analysis = analyze_forms(forms, object_names, parameters)
+    analysis = analyze_forms(forms, object_names, parameters, common_cell)
     _print_timing(1, time() - cpu_time)
 
     # Stage 2: intermediate representation
@@ -178,7 +193,7 @@ def compile_element(elements, prefix="Element", parameters=default_parameters())
 
     # Stage 1: analysis
     cpu_time = time()
-    analysis = analyze_elements(elements)
+    analysis = analyze_elements(elements, parameters)
     _print_timing(1, time() - cpu_time)
 
     # Stage 2: intermediate representation
