@@ -1,12 +1,26 @@
 "This module defines rules and algorithms for generating C++ code."
 
-__author__ = "Anders Logg (logg@simula.no) and friends"
-__date__ = "2009-12-16"
-__copyright__ = "Copyright (C) 2009-2010 " + __author__
-__license__  = "GNU GPL version 3 or any later version"
-
+# Copyright (C) 2009-2010 Anders Logg
+#
+# This file is part of FFC.
+#
+# FFC is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# FFC is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with FFC.  If not, see <http://www.gnu.org/licenses/>.
+#
 # Modified by Kristian B. Oelgaard 2010
 # Modified by Marie E. Rognes 2010
+#
+# First added:  2009-12-16
 # Last changed: 2011-02-21
 
 # Python modules
