@@ -2,11 +2,24 @@
 This module generates code which is more or less a C++ representation of the code
 found in FIAT_NEW."""
 
-__author__ = "Kristian B. Oelgaard (k.b.oelgaard@gmail.com)"
-__date__ = "2007-04-16"
-__copyright__ = "Copyright (C) 2007-2010 Kristian B. Oelgaard"
-__license__  = "GNU GPL version 3 or any later version"
-
+# Copyright (C) 2007-2010 Kristian B. Oelgaard
+#
+# This file is part of FFC.
+#
+# FFC is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# FFC is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with FFC.  If not, see <http://www.gnu.org/licenses/>.
+#
+# First added:  2007-04-16
 # Last changed: 2011-02-21
 
 # Python modules
