@@ -24,11 +24,25 @@ FIAT (functional.pt_dict) in the intermediate representation stage.
 
 """
 
-__author__ = "Marie E. Rognes (meg@simula.no)"
-__copyright__ = "Copyright (C) 2009"
-__license__  = "GNU GPL version 3 or any later version"
-
+# Copyright (C) 2009 Marie E. Rognes
+#
+# This file is part of FFC.
+#
+# FFC is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# FFC is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with FFC.  If not, see <http://www.gnu.org/licenses/>.
+#
 # Modified by Kristian B. Oelgaard 2010
+#
 # Last changed: 2010-02-09
 
 from ffc.cpp import format, remove_unused
