@@ -9,11 +9,24 @@ It relies on templates for UFC code available as part of the module
 ufc_utils.
 """
 
-__author__ = "Anders Logg (logg@simula.no) and friends"
-__date__ = "2009-12-16"
-__copyright__ = "Copyright (C) 2009 " + __author__
-__license__  = "GNU GPL version 3 or any later version"
-
+# Copyright (C) 2009 Anders Logg
+#
+# This file is part of FFC.
+#
+# FFC is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# FFC is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with FFC.  If not, see <http://www.gnu.org/licenses/>.
+#
+# First added:  2009-12-16
 # Last changed: 2011-02-21
 
 # Python modules
