@@ -1,10 +1,24 @@
 "Code generation for interpolate_vertex_values."
 
-__author__ = "Marie E. Rognes (meg@simula.no)"
-__copyright__ = "Copyright (C) 2009"
-__license__  = "GNU GPL version 3 or any later version"
-
+# Copyright (C) 2009 Marie E. Rognes
+#
+# This file is part of FFC.
+#
+# FFC is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# FFC is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with FFC.  If not, see <http://www.gnu.org/licenses/>.
+#
 # Modified by Kristian B. Oelgaard 2010
+#
 # Last changed: 2010-02-09
 
 from ffc.cpp import format, remove_unused
@@ -140,5 +154,5 @@ def _change_variables(mapping, dim, space_dim):
                                                   [G[j][index] for j in range(dim)])
                                             for index in range(space_dim)]
     else:
-        raise Exception, "No such mapping: %s accepted" % mapiping
+        raise Exception, "No such mapping: %s accepted" % mapping
     return change_of_variables
