@@ -5,12 +5,26 @@ This module reuses the corresponding log.py module from UFL which
 is a wrapper for the standard Python logging module.
 """
 
-__author__ = "Anders Logg (logg@simula.no)"
-__date__ = "2009-01-12"
-__copyright__ = "Copyright (C) 2009 Anders Logg"
-__license__  = "GNU GPL version 3 or any later version"
-
+# Copyright (C) 2009 Anders Logg
+#
+# This file is part of FFC.
+#
+# FFC is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# FFC is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with FFC.  If not, see <http://www.gnu.org/licenses/>.
+#
 # Modified by Kristian B. Oelgaard, 2009
+#
+# First added:  2009-01-12
 # Last changed: 2010-02-12
 
 # UFL modules
