@@ -1,10 +1,23 @@
 "This file implements a class to represent a fraction."
 
-__author__ = "Kristian B. Oelgaard (k.b.oelgaard@gmail.com)"
-__date__ = "2009-07-12"
-__copyright__ = "Copyright (C) 2009-2010 Kristian B. Oelgaard"
-__license__  = "GNU GPL version 3 or any later version"
-
+# Copyright (C) 2009-2010 Kristian B. Oelgaard
+#
+# This file is part of FFC.
+#
+# FFC is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# FFC is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with FFC.  If not, see <http://www.gnu.org/licenses/>.
+#
+# First added:  2009-07-12
 # Last changed: 2010-02-09
 
 # FFC modules.
@@ -283,13 +296,15 @@ class Fraction(Expr):
             for m in self.denom.vrs:
 #                d_found, d_remain = m.reduce_vartype(var_type)
                 foo = m.reduce_vartype(var_type)
-                if len(foo) != 1:
-                    raise RuntimeError("This case is not handled")
                 d_found, d_remain = foo[0]
                 # If we've found a denom, but the new found is different from
                 # the one already found, terminate loop since it wouldn't make
                 # sense to reduce the fraction.
-                if denom_found != None and repr(d_found) != repr(denom_found):
+                # TODO: handle I0/((I0 + I1)/(G0 + G1) + (I1 + I2)/(G1 + G2))
+                # better than just skipping.
+#                if len(foo) != 1:
+#                    raise RuntimeError("This case is not handled")
+                if len(foo) != 1 or (denom_found is not None and repr(d_found) != repr(denom_found)):
                     # If the denominator of the entire sum has a type which is
                     # lower than or equal to the vartype that we are currently
                     # reducing for, we have to move it outside the expression
