@@ -1,11 +1,25 @@
 "Quadrature representation class for UFL"
 
-__author__ = "Kristian B. Oelgaard (k.b.oelgaard@gmail.com)"
-__date__ = "2009-01-07"
-__copyright__ = "Copyright (C) 2009-2010 Kristian B. Oelgaard"
-__license__  = "GNU GPL version 3 or any later version"
-
+# Copyright (C) 2009-2010 Kristian B. Oelgaard
+#
+# This file is part of FFC.
+#
+# FFC is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# FFC is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with FFC.  If not, see <http://www.gnu.org/licenses/>.
+#
 # Modified by Anders Logg, 2009.
+#
+# First added:  2009-01-07
 # Last changed: 2010-05-18
 
 # UFL modules
@@ -14,12 +28,19 @@ from ufl.algorithms import extract_unique_elements, extract_type, extract_elemen
 
 # FFC modules
 from ffc.log import ffc_assert, info, error
-from ffc.fiatinterface import create_element, create_quadrature
+from ffc.fiatinterface import create_element
 from ffc.fiatinterface import map_facet_points
 from ffc.quadrature.quadraturetransformer import QuadratureTransformer
 from ffc.quadrature.optimisedquadraturetransformer import QuadratureTransformerOpt
+from ffc.quadrature_schemes import create_quadrature
 
-def compute_integral_ir(domain_type, domain_id, integrals, metadata, form_data, form_id, parameters):
+def compute_integral_ir(domain_type,
+                        domain_id,
+                        integrals,
+                        metadata,
+                        form_data,
+                        form_id,
+                        parameters):
     "Compute intermediate represention of integral."
 
     info("Computing quadrature representation")
@@ -36,7 +57,10 @@ def compute_integral_ir(domain_type, domain_id, integrals, metadata, form_data,
 
     # Sort integrals and tabulate basis.
     sorted_integrals = _sort_integrals(integrals, metadata, form_data)
-    integrals_dict, psi_tables, quad_weights = _tabulate_basis(sorted_integrals, domain_type, form_data.num_facets)
+    integrals_dict, psi_tables, quad_weights = \
+        _tabulate_basis(sorted_integrals,
+                        domain_type,
+                        form_data.num_facets)
 
     # Create dimensions of primary indices, needed to reset the argument 'A'
     # given to tabulate_tensor() by the assembler.
@@ -84,11 +108,15 @@ def compute_integral_ir(domain_type, domain_id, integrals, metadata, form_data,
 
     # Create transformer.
     if optimise_parameters["optimisation"]:
-        transformer = QuadratureTransformerOpt(psi_tables, quad_weights, \
-            form_data.geometric_dimension, optimise_parameters)
+        transformer = QuadratureTransformerOpt(psi_tables,
+                                               quad_weights,
+                                               form_data.geometric_dimension,
+                                               optimise_parameters)
     else:
-        transformer = QuadratureTransformer(psi_tables, quad_weights,\
-            form_data.geometric_dimension, optimise_parameters)
+        transformer = QuadratureTransformer(psi_tables,
+                                            quad_weights,
+                                            form_data.geometric_dimension,
+                                            optimise_parameters)
 
     # Add tables for weights, name_map and basis values.
     ir["quadrature_weights"]  = quad_weights
@@ -140,7 +168,7 @@ def _tabulate_basis(sorted_integrals, domain_type, num_facets):
         # Extract number of points and the rule.
         # TODO: The rule is currently unused because the fiatinterface does not
         # implement support for other rules than those defined in FIAT_NEW
-        num_points_per_axis, rule = pr
+        degree, rule = pr
 
         # Get all unique elements in integral.
         elements = extract_unique_elements(integral)
@@ -152,18 +180,12 @@ def _tabulate_basis(sorted_integrals, domain_type, num_facets):
         cell_domain = elements[0].cell().domain()
         facet_domain = elements[0].cell().facet_domain()
 
-        # TODO: These safety check could be removed for speed (I think?)
-        ffc_assert(all(cell_domain == e.cell().domain() for e in elements), \
-                    "The cell shape of all elements MUST be equal: " + repr(elements))
-        ffc_assert(all(facet_domain == e.cell().facet_domain() for e in elements), \
-                    "The facet shape of all elements MUST be equal: " + repr(elements))
-
         # Make quadrature rule and get points and weights.
         # FIXME: Make create_quadrature() take a rule argument.
         if domain_type == "cell":
-            (points, weights) = create_quadrature(cell_domain, num_points_per_axis)
+            (points, weights) = create_quadrature(cell_domain, degree, rule)
         elif domain_type == "exterior_facet" or domain_type == "interior_facet":
-            (points, weights) = create_quadrature(facet_domain, num_points_per_axis)
+            (points, weights) = create_quadrature(facet_domain, degree, rule)
         else:
             error("Unknown integral type: " + str(domain_type))
 
@@ -250,16 +272,12 @@ def _sort_integrals(integrals, metadata, form_data):
             if "quadrature_rule" in integral_metadata:
                 rule = integral_metadata["quadrature_rule"]
 
-        # FIXME: This could take place somewhere else?
-        # Compute the required number of points for each axis (exact integration).
-        num_points_per_axis = (degree + 1 + 1) / 2 # integer division gives 2m - 1 >= q.
-
-        # Create form and add to dictionary according to number of points and rule.
+        # Create form and add to dictionary according to degree and rule.
         form = Form([Integral(integral.integrand(), integral.measure().reconstruct(metadata={}))])
-        if not (num_points_per_axis, rule) in sorted_integrals:
-            sorted_integrals[(num_points_per_axis, rule)] = form
+        if not (degree, rule) in sorted_integrals:
+            sorted_integrals[(degree, rule)] = form
         else:
-            sorted_integrals[(num_points_per_axis, rule)] += form
+            sorted_integrals[(degree, rule)] += form
     # Extract integrals form forms.
     for key, val in sorted_integrals.items():
         if len(val.integrals()) != 1:
