@@ -1,12 +1,26 @@
 "QuadratureTransformer for quadrature code generation to translate UFL expressions."
 
-__author__ = "Kristian B. Oelgaard (k.b.oelgaard@gmail.com)"
-__date__ = "2009-02-09"
-__copyright__ = "Copyright (C) 2009-2010 Kristian B. Oelgaard"
-__license__  = "GNU GPL version 3 or any later version"
-
+# Copyright (C) 2009-2010 Kristian B. Oelgaard
+#
+# This file is part of FFC.
+#
+# FFC is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# FFC is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with FFC.  If not, see <http://www.gnu.org/licenses/>.
+#
 # Modified by Peter Brune, 2009
 # Modified by Anders Logg, 2009
+#
+# First added:  2009-02-09
 # Last changed: 2010-03-11
 
 # Python modules.
@@ -589,4 +603,3 @@ class QuadratureTransformer(QuadratureTransformerBase):
         used_psi_tables = set([v for k, v in self.psi_tables_map.items()])
 
         return (value, ops, [trans_set, used_points, used_psi_tables])
-
