@@ -1,10 +1,23 @@
 "QuadratureTransformerBase, a common class for quadrature transformers to translate UFL expressions."
 
-__author__ = "Kristian B. Oelgaard (k.b.oelgaard@gmail.com)"
-__date__ = "2009-10-13"
-__copyright__ = "Copyright (C) 2009-2010 Kristian B. Oelgaard"
-__license__  = "GNU GPL version 3 or any later version"
-
+# Copyright (C) 2009-2010 Kristian B. Oelgaard
+#
+# This file is part of FFC.
+#
+# FFC is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# FFC is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with FFC.  If not, see <http://www.gnu.org/licenses/>.
+#
+# First added:  2009-10-13
 # Last changed: 2010-03-11
 
 # Python modules.
@@ -37,7 +50,11 @@ class QuadratureTransformerBase(Transformer):
 #class QuadratureTransformerBase(ReuseTransformer):
     "Transform UFL representation to quadrature code."
 
-    def __init__(self, psi_tables, quad_weights, geo_dim, optimise_parameters):
+    def __init__(self,
+                 psi_tables,
+                 quad_weights,
+                 geo_dim,
+                 optimise_parameters):
 
         Transformer.__init__(self)
 
@@ -764,7 +781,10 @@ class QuadratureTransformerBase(Transformer):
     def _math_function(self, operands, format_function):
         error("This function should be implemented by the child class.")
 
-    def _get_auxiliary_variables(self, ufl_function, component, derivatives):
+    def _get_auxiliary_variables(self,
+                                 ufl_function,
+                                 component,
+                                 derivatives):
         "Helper function for both Coefficient and Argument."
 
         # Get local component (in case we have mixed elements).
@@ -780,6 +800,7 @@ class QuadratureTransformerBase(Transformer):
 
         # Get relevant sub element and mapping.
         sub_element = create_element(ufl_function.element().extract_component(tuple(component))[1])
+
         # Assuming that mappings for all basisfunctions are equal (they should be).
         transformation = sub_element.mapping()[0]
 
