@@ -12,13 +12,27 @@ function "foo", one should only need to use the data stored
 in the intermediate representation under the key "foo".
 """
 
-__author__ = "Anders Logg (logg@simula.no) and friends"
-__date__ = "2009-12-16"
-__copyright__ = "Copyright (C) 2009-2010 " + __author__
-__license__  = "GNU GPL version 3 or any later version"
-
+# Copyright (C) 2009-2010 Anders Logg
+#
+# This file is part of FFC.
+#
+# FFC is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# FFC is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with FFC.  If not, see <http://www.gnu.org/licenses/>.
+#
 # Modified by Marie E. Rognes 2010
 # Modified by Kristian B. Oelgaard 2010
+#
+# First added:  2009-12-16
 # Last changed: 2010-04-12
 
 # Python modules
@@ -51,30 +65,34 @@ def compute_ir(analysis, parameters):
     set_float_formatting(int(parameters["precision"]))
 
     # Extract data from analysis
-    forms, elements, element_map = analysis
+    form_datas, elements, element_numbers = analysis
 
     # Compute representation of elements
     info("Computing representation of %d elements" % len(elements))
-    ir_elements = [_compute_element_ir(e, i, element_map) for (i, e) in enumerate(elements)]
+    ir_elements = [_compute_element_ir(e, i, element_numbers) \
+                       for (i, e) in enumerate(elements)]
 
     # Compute representation of dofmaps
     info("Computing representation of %d dofmaps" % len(elements))
-    ir_dofmaps = [_compute_dofmap_ir(e, i, element_map) for (i, e) in enumerate(elements)]
+    ir_dofmaps = [_compute_dofmap_ir(e, i, element_numbers)
+                      for (i, e) in enumerate(elements)]
 
     # Compute and flatten representation of integrals
     info("Computing representation of integrals")
-    irs = [_compute_integral_ir(f, i, parameters) for (i, f) in enumerate(forms)]
+    irs = [_compute_integral_ir(fd, i, parameters) \
+               for (i, fd) in enumerate(form_datas)]
     ir_integrals = [ir for ir in chain(*irs) if not ir is None]
 
     # Compute representation of forms
     info("Computing representation of forms")
-    ir_forms = [_compute_form_ir(f, i, element_map) for (i, f) in enumerate(forms)]
+    ir_forms = [_compute_form_ir(fd, i, element_numbers) \
+                    for (i, fd) in enumerate(form_datas)]
 
     end()
 
     return ir_elements, ir_dofmaps, ir_integrals, ir_forms
 
-def _compute_element_ir(ufl_element, element_id, element_map):
+def _compute_element_ir(ufl_element, element_id, element_numbers):
     "Compute intermediate representation of element."
 
     # Create FIAT element
@@ -96,13 +114,13 @@ def _compute_element_ir(ufl_element, element_id, element_map):
     ir["evaluate_dof"] = _evaluate_dof(element, cell)
     ir["interpolate_vertex_values"] = _interpolate_vertex_values(element, cell)
     ir["num_sub_elements"] = ufl_element.num_sub_elements()
-    ir["create_sub_element"] = _create_sub_foo(ufl_element, element_map)
+    ir["create_sub_element"] = _create_sub_foo(ufl_element, element_numbers)
 
     #debug_ir(ir, "finite_element")
 
     return ir
 
-def _compute_dofmap_ir(ufl_element, element_id, element_map):
+def _compute_dofmap_ir(ufl_element, element_id, element_numbers):
     "Compute intermediate representation of dofmap."
 
     # Create FIAT element
@@ -134,7 +152,7 @@ def _compute_dofmap_ir(ufl_element, element_id, element_map):
     ir["tabulate_entity_dofs"] = (element.entity_dofs(), num_dofs_per_entity)
     ir["tabulate_coordinates"] = _tabulate_coordinates(element)
     ir["num_sub_dofmaps"] = ufl_element.num_sub_elements()
-    ir["create_sub_dofmap"] = _create_sub_foo(ufl_element, element_map)
+    ir["create_sub_dofmap"] = _create_sub_foo(ufl_element, element_numbers)
 
     #debug_ir(ir, "dofmap")
 
@@ -160,13 +178,13 @@ def _init_mesh(element):
 
     # return _num_dofs_per_entity(element)
 
-def _compute_integral_ir(form, form_id, parameters):
+def _compute_integral_ir(form_data, form_id, parameters):
     "Compute intermediate represention of form integrals."
 
     irs = []
 
     # Iterate over integrals
-    for (domain_type, domain_id, integrals, metadata) in form.form_data().integral_data:
+    for (domain_type, domain_id, integrals, metadata) in form_data.integral_data:
 
         # Select representation
         if metadata["representation"] == "quadrature":
@@ -181,7 +199,7 @@ def _compute_integral_ir(form, form_id, parameters):
                                    domain_id,
                                    integrals,
                                    metadata,
-                                   form.form_data(),
+                                   form_data,
                                    form_id,
                                    parameters)
 
@@ -190,28 +208,28 @@ def _compute_integral_ir(form, form_id, parameters):
 
     return irs
 
-def _compute_form_ir(form, form_id, element_map):
+def _compute_form_ir(form_data, form_id, element_numbers):
     "Compute intermediate representation of form."
 
-    # Extract form data
-    form_data = form.form_data()
-
     # Store id
     ir = {"id": form_id}
 
+    print "check 2", element_numbers
+    print [element_numbers[e] for e in form_data.elements]
+
     # Compute common data
     ir["classname"] = "FooForm"
     ir["members"] = not_implemented
     ir["constructor"] = not_implemented
     ir["destructor"] = not_implemented
-    ir["signature"] = repr(form)
+    ir["signature"] = repr(form_data.preprocessed_form)
     ir["rank"] = form_data.rank
     ir["num_coefficients"] = form_data.num_coefficients
     ir["num_cell_domains"] = form_data.num_cell_domains
     ir["num_exterior_facet_domains"] = form_data.num_exterior_facet_domains
     ir["num_interior_facet_domains"] = form_data.num_interior_facet_domains
-    ir["create_finite_element"] = [element_map[e] for e in form_data.elements]
-    ir["create_dofmap"] = [element_map[e] for e in form_data.elements]
+    ir["create_finite_element"] = [element_numbers[e] for e in form_data.elements]
+    ir["create_dofmap"] = [element_numbers[e] for e in form_data.elements]
     ir["create_cell_integral"] = _create_foo_integral("cell", form_data)
     ir["create_exterior_facet_integral"] = _create_foo_integral("exterior_facet", form_data)
     ir["create_interior_facet_integral"] = _create_foo_integral("interior_facet", form_data)
@@ -433,9 +451,9 @@ def _interpolate_vertex_values(element, cell):
                           for e in all_elements(element)]
     return ir
 
-def _create_sub_foo(ufl_element, element_map):
+def _create_sub_foo(ufl_element, element_numbers):
     "Compute intermediate representation of create_sub_element/dofmap."
-    return [element_map[e] for e in ufl_element.sub_elements()]
+    return [element_numbers[e] for e in ufl_element.sub_elements()]
 
 def _create_foo_integral(domain_type, form_data):
     "Compute intermediate representation of create_foo_integral."
