@@ -1,16 +1,30 @@
 "This module implements efficient integration of monomial forms."
 
-__author__ = "Anders Logg (logg@simula.no)"
-__date__ = "2004-11-03"
-__copyright__ = "Copyright (C) 2004-2009 Anders Logg"
-__license__  = "GNU GPL version 3 or any later version"
-
+# Copyright (C) 2004-2009 Anders Logg
+#
+# This file is part of FFC.
+#
+# FFC is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# FFC is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with FFC.  If not, see <http://www.gnu.org/licenses/>.
+#
 # Thanks to Robert C. Kirby for suggesting the initial algorithm that
 # this implementation is based on.
-
-# Modified by Garth N. Wells 2006
-# Modified by Marie E. Rognes (meg@math.uio.no) 2008
+#
+# Modified by Garth N. Wells, 2006
+# Modified by Marie E. Rognes, 2008
 # Modified by Kristian B. Oelgaard, 2009
+#
+# First added:  2004-11-03
 # Last changed: 2010-02-02
 
 # Python modules
@@ -23,15 +37,19 @@ from ufl.geometry import domain2facet
 
 # FFC modules
 from ffc.log import info, debug, error
-from ffc.fiatinterface import create_element, create_quadrature
+from ffc.fiatinterface import create_element
 from ffc.fiatinterface import map_facet_points
+from ffc.quadrature_schemes import create_quadrature
 
 # FFC tensor representation modules
 from multiindex import build_indices
 from monomialextraction import MonomialException
 from monomialtransformation import MonomialIndex
 
-def integrate(monomial, domain_type, facet0, facet1, quadrature_degree):
+def integrate(monomial,
+              domain_type,
+              facet0, facet1,
+              quadrature_degree):
     """Compute the reference tensor for a given monomial term of a
     multilinear form"""
 
@@ -41,13 +59,19 @@ def integrate(monomial, domain_type, facet0, facet1, quadrature_degree):
     tic = time.time()
 
     # Initialize quadrature points and weights
-    (points, weights) = _init_quadrature(monomial.arguments, domain_type, quadrature_degree)
+    (points, weights) = _init_quadrature(monomial.arguments,
+                                         domain_type,
+                                         quadrature_degree)
 
     # Initialize quadrature table for basis functions
-    table = _init_table(monomial.arguments, domain_type, points, facet0, facet1)
+    table = _init_table(monomial.arguments,
+                        domain_type,
+                        points,
+                        facet0, facet1)
 
     # Compute table Psi for each factor
-    psis = [_compute_psi(v, table, len(points), domain_type) for v in monomial.arguments]
+    psis = [_compute_psi(v, table, len(points), domain_type) \
+                for v in monomial.arguments]
 
     # Compute product of all Psis
     A0 = _compute_product(psis, monomial.float_value * weights)
@@ -64,18 +88,14 @@ def _init_quadrature(arguments, domain_type, quadrature_degree):
     "Initialize quadrature for given monomial."
 
     # Get shapes (check first factor, should be the same for all)
-    ufl_element = arguments[0].element
-    cell_shape = ufl_element.cell().domain()
+    cell_shape = arguments[0].element.cell().domain()
     facet_shape = domain2facet[cell_shape]
 
-    # Use the quadrature order given by metadata to compute the number of points
-    num_points = (quadrature_degree + 2) / 2
-
     # Create quadrature rule and get points and weights
     if domain_type == Measure.CELL:
-        (points, weights) = create_quadrature(cell_shape, num_points)
+        (points, weights) = create_quadrature(cell_shape, quadrature_degree)
     else:
-        (points, weights) = create_quadrature(facet_shape, num_points)
+        (points, weights) = create_quadrature(facet_shape, quadrature_degree)
 
     return (points, weights)
 
@@ -129,8 +149,7 @@ def _compute_psi(v, table, num_points, domain_type):
     # later when we sum over these dimensions.
 
     # Get cell dimension
-    ufl_element = v.element
-    cell_dimension = ufl_element.cell().geometric_dimension()
+    cell_dimension = v.element.cell().geometric_dimension()
 
     # Get indices and shapes for components
     if len(v.components) ==  0:
@@ -166,7 +185,8 @@ def _compute_psi(v, table, num_points, domain_type):
                 # Translate derivative multiindex to lookup tuple
                 dtuple = _multiindex_to_tuple(dlist, cell_dimension)
                 # Get values from table
-                Psi[component][tuple(dlist)] = etable[dtuple][:, cindex[0].index_range[component], :]
+                Psi[component][tuple(dlist)] = \
+                    etable[dtuple][:, cindex[0].index_range[component], :]
     else:
         etable = table[(v.element, v.restriction)]
         for dlist in dlists:
@@ -183,7 +203,8 @@ def _compute_psi(v, table, num_points, domain_type):
     # Remove fixed indices
     for i in range(num_indices[0]):
         Psi = Psi[0, ...]
-    indices = [index for index in indices if not index.index_type == MonomialIndex.FIXED]
+    indices = [index for index in indices \
+                   if not index.index_type == MonomialIndex.FIXED]
 
     # Put quadrature points first
     rank = numpy.rank(Psi)
