@@ -1,12 +1,26 @@
 "Transformation of monomial representations of UFL forms."
 
-__author__ = "Anders Logg (logg@simula.no)"
-__date__ = "2009-03-06"
-__copyright__ = "Copyright (C) 2009 Anders Logg"
-__license__  = "GNU GPL version 3 or any later version"
-
+# Copyright (C) 2009 Anders Logg
+#
+# This file is part of FFC.
+#
+# FFC is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# FFC is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with FFC.  If not, see <http://www.gnu.org/licenses/>.
+#
 # Modified by Kristian B. Oelgaard, 2009
 # Modified by Marie E. Rognes, 2010
+#
+# First added:  2009-03-06
 # Last changed: 2010-02-17
 
 # UFL modules
