@@ -1,14 +1,28 @@
 "Code generator for tensor representation"
 
-__author__ = "Anders Logg (logg@simula.no)"
-__date__ = "2004-11-03"
-__copyright__ = "Copyright (C) 2004-2010 Anders Logg"
-__license__  = "GNU GPL version 3 or any later version"
-
+# Copyright (C) 2004-2010 Anders Logg
+#
+# This file is part of FFC.
+#
+# FFC is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# FFC is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with FFC.  If not, see <http://www.gnu.org/licenses/>.
+#
 # Modified by Kristian B. Oelgaard, 2009-2010
-# Modified by Marie Rognes (meg@math.uio.no), 2007
+# Modified by Marie Rognes, 2007
 # Modified by Garth N. Wells, 2009
 # Modified by Mehdi Nikbakht, 2010
+#
+# First added:  2004-11-03
 # Last changed: 2011-02-21
 
 # FFC modules
