@@ -1,9 +1,22 @@
-__author__ = "Anders Logg (logg@simula.no)"
-__date__ = "2010-01-18"
-__copyright__ = "Copyright (C) 2010 " + __author__
-__license__  = "GNU GPL version 3 or any later version"
-
-# Last changed: 2011-02-21
+# Copyright (C) 2010 Anders Logg
+#
+# This file is part of FFC.
+#
+# FFC is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# FFC is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with FFC.  If not, see <http://www.gnu.org/licenses/>.
+#
+# First added:  2010-01-18
+# Last changed: 2011-03-22
 
 # Python modules
 from itertools import chain
@@ -37,60 +50,61 @@ def _generate_dolfin_wrapper(analysis, prefix, parameters):
 
     begin("Compiler stage 4.1: Generating additional wrapper code")
 
-    # Extract data from analysis
-    forms, elements, element_map = analysis
-
     # Encapsulate data
-    (capsules, common_space) = _encapsulate(prefix, forms, elements,
-                                           element_map, parameters)
+    (capsules, common_space) = _encapsulate(prefix, analysis, parameters)
 
     # Generate code
     info("Generating wrapper code for DOLFIN")
     from dolfin_utils.wrappers import generate_dolfin_code
-    code = generate_dolfin_code(prefix, "", capsules, common_space) + "\n\n"
+    code = generate_dolfin_code(prefix, "", capsules, common_space,
+                                error_control=parameters["error_control"])
+    code += "\n\n"
     end()
 
     return code
 
-def _encapsulate(prefix, forms, elements, element_map, parameters):
+def _encapsulate(prefix, analysis, parameters):
 
-    num_forms = len(forms)
+    # Extract data from analysis
+    form_datas, elements, element_map = analysis
+
+    num_form_datas = len(form_datas)
     common_space = False
 
     # Special case: single element
-    if num_forms == 0:
+    if num_form_datas == 0:
         capsules = _encapsule_element(prefix, elements)
 
     # Special case: with error control
-    elif (parameters["error_control"] and num_forms == 11):
-        capsules = [_encapsule_form(prefix, form, i, element_map) for
-                    (i, form) in enumerate(forms[:num_forms-1])]
-        capsules += [_encapsule_form(prefix, forms[-1], num_forms-1,
+    elif (parameters["error_control"] and num_form_datas == 11):
+        capsules = [_encapsule_form(prefix, form_data, i, element_map) for
+                    (i, form_data) in enumerate(form_datas[:num_form_datas-1])]
+        capsules += [_encapsule_form(prefix, form_datas[-1], num_form_datas-1,
                                      element_map, "GoalFunctional")]
 
     # Otherwise: generate standard capsules for each form
     else:
-        capsules = [_encapsule_form(prefix, form, i, element_map) for
-                    (i, form) in enumerate(forms)]
+        capsules = [_encapsule_form(prefix, form_data, i, element_map) for
+                    (i, form_data) in enumerate(form_datas)]
 
         # Check if all elements are equal
         elements = []
-        for form in forms:
-            elements += form.form_data().elements[:form.form_data().rank]
+        for form_data in form_datas:
+            elements += form_data.elements[:form_data.rank]
         common_space = all_equal(elements)
 
     return (capsules, common_space)
 
 
-def _encapsule_form(prefix, form, i, element_map, superclassname=None):
-    element_numbers = [element_map[e] for e in form.form_data().elements]
+def _encapsule_form(prefix, form_data, i, element_map, superclassname=None):
+    element_numbers = [element_map[e] for e in form_data.elements]
 
     if superclassname is None:
         superclassname = "Form"
 
     from dolfin_utils.wrappers import UFCFormNames
     form_names = UFCFormNames("%d" % i,
-                              form.form_data().coefficient_names,
+                              form_data.coefficient_names,
                               format["classname form"](prefix, i),
                               [format["classname finite_element"](prefix, j)
                                for j in element_numbers],
