@@ -1,10 +1,23 @@
 #!/usr/bin/env python
 
-__author__ = "Kristian B. Oelgaard (k.b.oelgaard@gmail.com)"
-__date__ = "2010-01-06"
-__copyright__ = "Copyright (C) 2010 Kristian B. Oelgaard"
-__license__  = "GNU GPL version 3 or any later version"
-
+# Copyright (C) 2010 Kristian B. Oelgaard
+#
+# This file is part of FFC.
+#
+# FFC is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# FFC is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with FFC.  If not, see <http://www.gnu.org/licenses/>.
+#
+# First added:  2010-01-06
 # Last changed: 2010-02-01
 
 # Pyhton modules
@@ -33,9 +46,12 @@ class TestReduceVarType(unittest.TestCase):
 
         I0 = Symbol("I0", IP)
         I1 = Symbol("I1", IP)
+        I2 = Symbol("I2", IP)
         I5 = Product([f5, I0])
 
         G0 = Symbol("G0", GEO)
+        G1 = Symbol("G1", GEO)
+        G2 = Symbol("G2", GEO)
         G3 = Product([f3, G0])
 
 
@@ -58,6 +74,11 @@ class TestReduceVarType(unittest.TestCase):
         F3 = Fraction(G3,S3).expand()
         F4 = Fraction(I1, Sum([I1, I0]))
         F5 = Fraction(S5, I1)
+        F6 = Fraction(I0,
+              Sum([
+                Fraction(Sum([I0,I1]), Sum([G0,G1])),
+                Fraction(Sum([I1,I2]), Sum([G1,G2])),
+              ]))
 
         r0 = B0.reduce_vartype(BASIS)
         r1 = B0.reduce_vartype(CONST)
@@ -80,6 +101,7 @@ class TestReduceVarType(unittest.TestCase):
         rf4 = F3.reduce_vartype(BASIS)
         rf5 = F4.reduce_vartype(IP)
         rf6 = F5.reduce_vartype(IP)
+        rf7 = F6.reduce_vartype(IP)
 #        print
 #        print "%s, red(BASIS): ('%s', '%s')" %(B0, r0[0][0], r0[0][1])
 #        print "%s, red(CONST): ('%s', '%s')" %(B0, r1[0][0], r1[0][1])
@@ -102,6 +124,7 @@ class TestReduceVarType(unittest.TestCase):
 #        print "rf4: %s, red(BASIS): ('%s', '%s')" %(F3, rf4[0][0], rf4[0][1])
 #        print "rf5: %s, red(IP): ('%s', '%s')" %(F4, rf5[0][0], rf5[0][1])
 #        print "rf6: %s, red(IP): ('%s', '%s') + ('%s', '%s')" %(F5, rf6[0][0], rf6[0][1], rf6[1][0], rf6[1][1])
+#        print "rf7: %s, red(IP): ('%s', '%s')" %(F6, rf7[0][0], rf7[0][1])
 
         self.assertEqual([(B0, f1)], r0)
         self.assertEqual([((), B0)], r1)
@@ -137,6 +160,26 @@ class TestReduceVarType(unittest.TestCase):
         self.assertEqual(f1, rf6[0][1])
         self.assertEqual(Fraction(f1,I1), rf6[1][0])
         self.assertEqual(G0, rf6[1][1])
+        self.assertEqual(F6, rf7[0][0])
+        self.assertEqual(f1, rf7[0][1])
+
+        expr = Sum([Symbol('W1', GEO), Fraction(Symbol('det', GEO), Sum([Symbol('F0', IP), Symbol('K_11', GEO)]))])
+        red = expr.expand().reduce_vartype(IP)
+        vals = []
+        for ip in red:
+            ip_dec, geo = ip
+            if ip_dec and geo:
+                vals.append(Product([ip_dec, geo]))
+            elif geo:
+                vals.append(geo)
+            elif ip_dec:
+                vals.append(ip_dec)
+        comb = Sum(vals).expand()
+        K_11 = 1.4
+        F0   = 1.5
+        W1   = 1.9
+        det  = 2.1
+        self.assertAlmostEqual(eval(str(expr)), eval(str(comb)))
 
 if __name__ == "__main__":
 
